@@ -8,31 +8,35 @@
 #define WANT_CHARACTER_CLASSES_IN_SCANF
 #define WANT_NULL_PRINTF
 #define WANT_LONGLONG_PRINTF
+#define WANT_LONGLONG_SCANF
 
 /* 128 or 2048 bytes buffer size? */
 /* #define WANT_SMALL_STDIO_BUFS */
 
-/* this is only for meaningful for ttyname so far */
-#define SLASH_PROC_OK 1
+/* want fread to read() directly if size of data is larger than buffer?
+ * This costs a few bytes but is worth it if the application is already
+ * buffering. */
+#define WANT_FREAD_OPTIMIZATION
+
+/* this is only for meaningful for ttyname and sysconf_cpus so far */
+#define SLASH_PROC_OK
 
 /* use errno_location instead of errno */
 #define WANT_THREAD_SAFE
 
-/* make the startcode, etc. dynamic aware */
-/* #undef WANT_DYNAMIC */
+/* make the startcode, etc. dynamic aware ({con,de}structors) */
+/* #define WANT_DYNAMIC */
 
 /* do you want smaller or faster string routines? */
 /* #define WANT_FASTER_STRING_ROUTINES */
 
+/* define this to have strncpy zero-fill and not just zero-terminate the
+ * string */
+/* #define WANT_FULL_POSIX_COMPAT */
+
 /* read the comment in lib/strncat.c for an explanation */
 /* #define WANT_NON_COMPLIANT_STRNCAT */
 
-/* strsep, according to the Linux man page, when called on "foo,bar"
- * with separator ",", should return "foo" and then NULL.  glibc,
- * however, returns "foo", then "bar", and then NULL.  The man page
- * behaviour breaks openssh, so you might want to have glibc behaviour. */
-#define WANT_BUGGY_GLIBC_STRSEP
-
 #define WANT_LINKER_WARNINGS
 
 /* you need to define this if you want to run your programs with large
@@ -48,6 +52,9 @@
  * embedded environments. */
 #define WANT_FULL_RESOLV_CONF
 
+/* do you want IPv6 transport support in the DNS resolver? */
+#define WANT_IPV6_DNS
+
 /* do you want gethostbyname and friends to consult /etc/hosts? */
 #define WANT_ETC_HOSTS
 
@@ -61,23 +68,37 @@
 #define WANT_CRYPT_MD5
 
 /* do you want diet to include a safeguard dependency to make linking
- * against glibc fail? */
+ * against glibc fail?  This may fail with older binutils. */
 #define WANT_SAFEGUARD
 
+/* dy you want that malloc(0) return a pointer to a "zero-length" object
+ * that is realloc-able; means realloc(..,size) gives a NEW object (like a
+ * call to malloc(size)).
+ * WARNING: this violates C99 */
+/* #define WANT_MALLOC_ZERO */
+
+
 /* stop uncommenting here ;-) */
 #ifndef WANT_FASTER_STRING_ROUTINES
 #define WANT_SMALL_STRING_ROUTINES
 #endif
 
 #ifdef WANT_THREAD_SAFE
+#ifndef __ASSEMBLER__
 #define errno (*__errno_location())
 #define _REENTRANT
 #endif
+#endif
 
 #ifdef __DYN_LIB
+/* with shared libraries you MUST have a dynamic aware startcode */
 #ifndef WANT_DYNAMIC
 #define WANT_DYNAMIC
 #endif
+/* saveguard crashes with shared objects ... */
+#ifdef WANT_SAFEGUARD
+#undef WANT_SAFEGUARD
+#endif
 #endif
 
 #endif
