@@ -14,6 +14,8 @@ __fflush_stderr:
 flockfile:
 .weak funlockfile
 funlockfile:
+.weak __nop
+__nop:
 .global __you_tried_to_link_a_dietlibc_object_against_glibc
 __you_tried_to_link_a_dietlibc_object_against_glibc:
 
