@@ -23,8 +23,10 @@ typedef int32_t __s32;
 typedef int64_t __s64;
 #endif
 
-typedef size_t __kernel_size_t;
-
-typedef struct { int val[2]; } __kernel_fsid_t;
+#if defined(__alpha__)
+typedef unsigned long __kernel_size_t;
+#else
+typedef unsigned int __kernel_size_t;
+#endif
 
 #endif
