@@ -39,7 +39,7 @@ void seekdir (DIR *__dirp, long int __pos) __THROW;
 long int telldir (DIR *__dirp) __THROW;
 
 int scandir(const char *dir, struct dirent ***namelist,
-      int (*select)(const struct dirent *),
+      int (*selection)(const struct dirent *),
       int (*compar)(const struct dirent **, const struct dirent **)) __THROW;
 
 int alphasort(const struct dirent **a, const struct dirent **b) __THROW __attribute__((const));
@@ -50,4 +50,9 @@ int alphasort(const struct dirent **a, const struct dirent **b) __THROW __attrib
 extern int dirfd(DIR *dirp) __THROW;
 #endif
 
+#if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
+#define dirent dirent64
+#define readdir readdir64
+#endif
+
 #endif
