@@ -19,6 +19,13 @@ typedef struct _pthread_descr_struct *_pthread_descr;
 typedef int pthread_t;
 
 /* Fast locks */
+#ifdef __parisc__
+#define PTHREAD_SPIN_LOCKED 0
+#define PTHREAD_SPIN_UNLOCKED 1
+#else
+#define PTHREAD_SPIN_LOCKED 1
+#define PTHREAD_SPIN_UNLOCKED 0
+#endif
 struct _pthread_fastlock {
   int __spinlock;
 };
@@ -46,13 +53,13 @@ enum
 };
 
 #define PTHREAD_MUTEX_INITIALIZER \
-{{0}, 0, PTHREAD_MUTEX_FAST_NP, 0}
+{{PTHREAD_SPIN_UNLOCKED}, 0, PTHREAD_MUTEX_FAST_NP, 0}
 
 #define PTHREAD_RECURSIVE_MUTEX_INITIALIZER_NP \
-{{0}, 0, PTHREAD_MUTEX_RECURSIVE_NP, 0}
+{{PTHREAD_SPIN_UNLOCKED}, 0, PTHREAD_MUTEX_RECURSIVE_NP, 0}
 
 #define PTHREAD_ERRORCHECK_MUTEX_INITIALIZER_NP \
-{{0}, 0, PTHREAD_MUTEX_ERRORCHECK_NP, 0}
+{{PTHREAD_SPIN_UNLOCKED}, 0, PTHREAD_MUTEX_ERRORCHECK_NP, 0}
 
 typedef struct {
   int __mutexkind;
@@ -80,7 +87,7 @@ typedef struct {
 } pthread_cond_t;
 
 #define PTHREAD_COND_INITIALIZER \
-{{0},0}
+{{PTHREAD_SPIN_UNLOCKED},0}
 
 int pthread_cond_init(pthread_cond_t *cond, pthread_condattr_t *cond_attr);
 int pthread_cond_destroy(pthread_cond_t *cond);
@@ -218,7 +225,7 @@ pid_t pthread_atfork(void (*prepare)(void), void (*parent)(void),
 		     void (*child)(void));
 
 /* THREADS */
-int pthread_create (pthread_t *__thread,
+int pthread_create (pthread_t *__threadarg,
 		const pthread_attr_t *__attr,
 		void *(*__start_routine) (void *),
 		void *__arg);
@@ -232,4 +239,6 @@ int pthread_detach (pthread_t __th);
 pthread_t pthread_self (void);
 int pthread_equal (pthread_t __thread1, pthread_t __thread2);
 
+int pthread_sigmask(int how, const sigset_t*newset, sigset_t *oldset);
+
 #endif
