@@ -1,8 +1,6 @@
 #ifndef _SYS_CDEFS_H
 #define _SYS_CDEFS_H
 
-#define __dietlibc__
-
 #ifndef __cplusplus
 #define __THROW
 #define __BEGIN_DECLS
@@ -18,11 +16,10 @@
 #define __extension__
 #endif
 
-#define __pure__
-#ifdef __GNUC__
 #if (__GNUC__ > 2) || ((__GNUC__ == 2) && (__GNUC_MINOR__ >= 96))
-#undef __pure__
 #define __pure__ __attribute__ ((__pure__))
+#else
+#define __pure__
 #endif
 
 #if (__GNUC__ == 2) && (__GNUC_MINOR__ < 95)
@@ -30,13 +27,17 @@
 #endif
 
 #ifndef __STRICT_ANSI__
-#if (__GNUC__ < 3)
+#if __GNUC__ < 3
 #define __builtin_expect(foo,bar) (foo)
 #define expect(foo,bar) (foo)
 #else
 #define expect(foo,bar) __builtin_expect(foo,bar)
+#define __attribute_malloc__ __attribute__((malloc))
 #endif
 #endif
+
+#ifndef __attribute_malloc__
+#define __attribute_malloc__
 #endif
 
 #define __P(x) x
@@ -47,10 +48,6 @@
 #define inline
 #endif
 
-#ifndef __GNUC__
-#define __extension__
-#endif
-
 #ifndef __i386__
 #define regparm(x)
 #endif
