@@ -3,7 +3,7 @@
 
 #include <sys/cdefs.h>
 
-#if defined(__i386__)
+#if defined(__i386__) || defined(__x86_64__) || defined(__ia64__)
 #include <sys/i386-ioctl.h>
 #elif defined(__alpha__)
 #include <sys/alpha-ioctl.h>
@@ -15,6 +15,10 @@
 #include <sys/mips-ioctl.h>
 #elif defined(__powerpc__)
 #include <sys/ppc-ioctl.h>
+#elif defined(__s390__)
+#include <sys/s390-ioctl.h>
+#elif defined(__hppa__)
+#include <sys/hppa-ioctl.h>
 #endif
 
 int ioctl(int d, int request, ...) __THROW;
