@@ -15,6 +15,26 @@
 #define MAP_SHARED	0x01		/* Share changes */
 #define MAP_PRIVATE	0x02		/* Changes are private */
 
+#ifdef __mips__
+#define MAP_FIXED	0x010		/* Interpret addr exactly */
+#define MAP_NORESERVE	0x0400		/* don't check for reservations */
+#define MAP_ANONYMOUS	0x0800		/* don't use a file */
+#define MAP_GROWSDOWN	0x1000		/* stack-like segment */
+#define MAP_DENYWRITE	0x2000		/* ETXTBSY */
+#define MAP_EXECUTABLE	0x4000		/* mark it as an executable */
+#define MAP_LOCKED	0x8000		/* pages are locked */
+#define MS_ASYNC	0x0001		/* sync memory asynchronously */
+#define MS_INVALIDATE	0x0002		/* invalidate mappings & caches */
+#define MS_SYNC		0x0004		/* synchronous memory sync */
+#define MCL_CURRENT	1		/* lock all current mappings */
+#define MCL_FUTURE	2		/* lock all future mappings */
+#define MADV_NORMAL	0x0		/* default page-in behavior */
+#define MADV_RANDOM	0x1		/* page-in minimum required */
+#define MADV_SEQUENTIAL	0x2		/* read-ahead aggressively */
+#define MADV_WILLNEED	0x3		/* pre-fault pages */
+#define MADV_DONTNEED	0x4		/* discard these pages */
+#else
+
 #ifdef __alpha__
 #define MAP_FIXED	0x100		/* Interpret addr exactly */
 #define MAP_ANONYMOUS	0x10		/* don't use a file */
@@ -39,7 +59,7 @@
 #define MAP_ANONYMOUS	0x20		/* don't use a file */
 #endif
 
-#if defined(__i386__)
+#if defined(__i386__) || defined(__s390__) || defined(__x86_64__)
 #define MAP_GROWSDOWN	0x0100		/* stack-like segment */
 #define MAP_DENYWRITE	0x0800		/* ETXTBSY */
 #define MAP_EXECUTABLE	0x1000		/* mark it as an executable */
@@ -91,6 +111,46 @@
 #define MADV_SEQUENTIAL	0x2		/* read-ahead aggressively */
 #define MADV_WILLNEED	0x3		/* pre-fault pages */
 #define MADV_DONTNEED	0x4		/* discard these pages */
+
+#elif defined(__hppa__)
+#define MAP_TYPE    0x03        /* Mask for type of mapping */
+#define MAP_FIXED   0x04        /* Interpret addr exactly */
+#define MAP_ANONYMOUS   0x10        /* don't use a file */
+
+#define MAP_DENYWRITE   0x0800      /* ETXTBSY */
+#define MAP_EXECUTABLE  0x1000      /* mark it as an executable */
+#define MAP_LOCKED  0x2000      /* pages are locked */
+#define MAP_NORESERVE   0x4000      /* don't check for reservations */
+#define MAP_GROWSDOWN   0x8000      /* stack-like segment */
+
+#define MS_SYNC     1       /* synchronous memory sync */
+#define MS_ASYNC    2       /* sync memory asynchronously */
+#define MS_INVALIDATE   4       /* invalidate the caches */
+
+#define MCL_CURRENT 1       /* lock all current mappings */
+#define MCL_FUTURE  2
+
+#elif defined(__ia64__)
+
+#define MAP_TYPE    0x0f        /* Mask for type of mapping */
+#define MAP_FIXED   0x10        /* Interpret addr exactly */
+#define MAP_ANONYMOUS   0x20        /* don't use a file */
+
+#define MAP_GROWSDOWN   0x0100      /* stack-like segment */
+#define MAP_GROWSUP 0x0200      /* register stack-like segment */
+#define MAP_DENYWRITE   0x0800      /* ETXTBSY */
+#define MAP_EXECUTABLE  0x1000      /* mark it as an executable */
+#define MAP_LOCKED  0x2000      /* pages are locked */
+#define MAP_NORESERVE   0x4000      /* don't check for reservations */
+#define MAP_WRITECOMBINED 0x10000   /* write-combine the area */
+#define MAP_NONCACHED   0x20000     /* don't cache the memory */
+
+#define MS_ASYNC    1       /* sync memory asynchronously */
+#define MS_INVALIDATE   2       /* invalidate the caches */
+#define MS_SYNC     4       /* synchronous memory sync */
+
+#endif
+
 #endif
 
 /* compatibility flags */
