@@ -4,7 +4,7 @@
 #include <sys/cdefs.h>
 #include <sys/types.h>
 
-#if defined(__i386__)
+#if defined(__i386__) || defined(__x86_64__)
 struct stat {
 	unsigned short st_dev;
 	unsigned short __pad1;
@@ -296,6 +296,126 @@ __extension__	long long	st_size;
 
 __extension__	unsigned long long	st_ino;
 };
+#elif defined(__s390__)
+struct stat {
+	unsigned short st_dev;
+	unsigned short __pad1;
+	unsigned long  st_ino;
+	unsigned short st_mode;
+	unsigned short st_nlink;
+	unsigned short st_uid;
+	unsigned short st_gid;
+	unsigned short st_rdev;
+	unsigned short __pad2;
+	unsigned long  st_size;
+	unsigned long  st_blksize;
+	unsigned long  st_blocks;
+	unsigned long  st_atime;
+	unsigned long  __unused1;
+	unsigned long  st_mtime;
+	unsigned long  __unused2;
+	unsigned long  st_ctime;
+	unsigned long  __unused3;
+	unsigned long  __unused4;
+	unsigned long  __unused5;
+};
+struct stat64 {
+	unsigned char	__pad0[6];
+	unsigned short	st_dev;
+	unsigned int	__pad1;
+#define STAT64_HAS_BROKEN_ST_INO        1
+	unsigned long	__st_ino;
+	unsigned int	st_mode;
+	unsigned int	st_nlink;
+	unsigned long	st_uid;
+	unsigned long	st_gid;
+	unsigned char	__pad2[6];
+	unsigned short	st_rdev;
+	unsigned int	__pad3;
+__extension__	long long	st_size;
+	unsigned long	st_blksize;
+	unsigned char	__pad4[4];
+	unsigned long	__pad5; 	/* future possible st_blocks high bits */
+	unsigned long	st_blocks;	/* Number 512-byte blocks allocated. */
+	unsigned long	st_atime;
+	unsigned long	__pad6;
+	unsigned long	st_mtime;
+	unsigned long	__pad7;
+	unsigned long	st_ctime;
+	unsigned long	__pad8; 	/* will be high 32 bits of ctime someday */
+__extension__	unsigned long long	st_ino;
+};
+
+#elif defined(__hppa__)
+
+struct stat {
+	unsigned long long st_dev;
+	unsigned short int _pad1;
+	unsigned long st_ino;
+	unsigned long st_mode;
+	unsigned long st_nlink;
+	unsigned long st_uid;
+	unsigned long st_gid;
+	unsigned long long st_rdev;
+	unsigned short int _pad2;
+	unsigned long st_size;
+	unsigned long st_blksize;
+	unsigned long st_blocks;
+	unsigned long st_atime;
+	unsigned long int unused1;
+	unsigned long st_mtime;
+	unsigned long int unused2;
+	unsigned long st_ctime;
+	unsigned long int unused3;
+	unsigned long long unused4;
+};
+
+struct stat64 {
+	unsigned long long st_dev;
+	unsigned int __pad1;
+	unsigned long __st_ino;
+	unsigned long st_mode;
+	unsigned long st_nlink;
+	unsigned long st_uid;
+	unsigned long st_gid;
+	unsigned long long st_rdev;
+	unsigned int __pad2;
+	unsigned long long st_size;
+	unsigned long long st_blksize;
+
+	unsigned long long st_blocks;
+ 	unsigned long st_atime;
+	unsigned long int __unused1;
+	unsigned long st_mtime;
+	unsigned long int __unused2;
+	unsigned long st_ctime;
+	unsigned long int __unused3;
+	unsigned long long st_ino;
+};
+
+#elif defined(__ia64__)
+
+struct stat {
+	unsigned long st_dev;
+	unsigned long st_ino;
+	unsigned long st_nlink;
+	unsigned int  st_mode;
+	unsigned int  st_uid;
+	unsigned int  st_gid;
+	unsigned int  __pad;
+	unsigned long st_rdev;
+	unsigned long st_size;
+	unsigned long st_atime;
+	unsigned long reserved;
+	unsigned long st_mtime;
+	unsigned long reserved2;
+	unsigned long st_ctime;
+	unsigned long reserved3;
+	unsigned long st_blksize;
+	long          st_blocks;
+	unsigned long pad[3];
+};
+
 #endif
 
 #define S_IFMT  00170000
@@ -349,12 +469,12 @@ extern int fstat64(int __fd, struct stat64 *__buf) __THROW;
 extern int lstat64(const char *__file, struct stat64 *__buf) __THROW;
 #endif
 
-#if _FILE_OFFSET_BITS == 64
-#define lstat(file,buf) lstat64(file,buf)
-#define fstat(file,buf) fstat64(file,buf)
+#if defined _FILE_OFFSET_BITS && _FILE_OFFSET_BITS == 64
+#define lstat lstat64
+#define fstat fstat64
 #define stat stat64
-#define pread(fd,buf,count,offset) pread64(fd,buf,count,offset)
-#define pwrite(fd,buf,count,offset) pwrite64(fd,buf,count,offset)
+#define pread pread64
+#define pwrite pwrite64
 #endif
 
 #define major(dev) (((dev)>>8) & 0xff)
