@@ -16,6 +16,7 @@
 #include <sys/types.h>
 #include <stddef.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <sys/shm.h>	/* for PAGE_SIZE */
 
@@ -142,24 +143,34 @@ void __libc_free(void *ptr) __attribute__((alias("_alloc_libc_free")));
 void free(void *ptr) __attribute__((weak,alias("_alloc_libc_free")));
 void if_freenameindex(void* ptr) __attribute__((alias("free")));
 
+#ifdef WANT_MALLOC_ZERO
+static __alloc_t zeromem[2]={{0},{0}};
+#endif
+
 static void* _alloc_libc_malloc(size_t size) {
   __alloc_t* ptr;
   size_t need;
-  if (size) {
-    size+=sizeof(__alloc_t);
-    if (size<=__MAX_SMALL_SIZE) {
-      need=GET_SIZE(size);
-      if ((ptr=__small_malloc(need))==MAP_FAILED) goto err_out;
-    }
-    else {
-      need=PAGE_ALIGN(size);
-      if ((ptr=do_mmap(need))==MAP_FAILED) goto err_out;
-    }
-    ptr->size=need;
-    return BLOCK_RET(ptr);
+#ifdef WANT_MALLOC_ZERO
+  if (!size) return BLOCK_RET(zeromem);
+#else
+  if (!size) goto retzero;
+#endif
+  size+=sizeof(__alloc_t);
+  if (size<sizeof(__alloc_t)) goto retzero;
+  if (size<=__MAX_SMALL_SIZE) {
+    need=GET_SIZE(size);
+    ptr=__small_malloc(need);
   }
+  else {
+    need=PAGE_ALIGN(size);
+    if (!need) ptr=MAP_FAILED; else ptr=do_mmap(need);
+  }
+  if (ptr==MAP_FAILED) goto err_out;
+  ptr->size=need;
+  return BLOCK_RET(ptr);
 err_out:
   (*__errno_location())=ENOMEM;
+retzero:
   return 0;
 }
 void* __libc_malloc(size_t size) __attribute__((alias("_alloc_libc_malloc")));
@@ -167,6 +178,10 @@ void* malloc(size_t size) __attribute__((weak,alias("_alloc_libc_malloc")));
 
 void *calloc(size_t nmemb, size_t _size) {
   register size_t size=_size*nmemb;
+  if (nmemb && size/nmemb!=_size) {
+    (*__errno_location())=ENOMEM;
+    return 0;
+  }
   return malloc(size);
 }
 
@@ -177,6 +192,7 @@ void* __libc_realloc(void* ptr, size_t _size) {
     if (size) {
       __alloc_t* tmp=BLOCK_START(ptr);
       size+=sizeof(__alloc_t);
+      if (size<sizeof(__alloc_t)) goto retzero;
       size=(size<=__MAX_SMALL_SIZE)?GET_SIZE(size):PAGE_ALIGN(size);
       if (tmp->size!=size) {
 	if ((tmp->size<=__MAX_SMALL_SIZE)) {
@@ -185,7 +201,7 @@ void* __libc_realloc(void* ptr, size_t _size) {
 	    register __alloc_t* foo=BLOCK_START(new);
 	    size=foo->size;
 	    if (size>tmp->size) size=tmp->size;
-	    memcpy(new,ptr,size-sizeof(__alloc_t));
+	    if (size) memcpy(new,ptr,size-sizeof(__alloc_t));
 	    _alloc_libc_free(ptr);
 	  }
 	  ptr=new;
@@ -195,6 +211,7 @@ void* __libc_realloc(void* ptr, size_t _size) {
 	  size=PAGE_ALIGN(size);
 	  foo=mremap(tmp,tmp->size,size,MREMAP_MAYMOVE);
 	  if (foo==MAP_FAILED) {
+retzero:
 	    (*__errno_location())=ENOMEM;
 	    ptr=0;
 	  }
