@@ -2,6 +2,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <string.h>
 #include "dietstdio.h"
 
 struct str_data {
@@ -15,9 +16,11 @@ static int swrite(void*ptr, size_t nmemb, struct str_data* sd) {
   if (tmp>0) {
     size_t len=nmemb;
     if (len>tmp) len=tmp;
-    memcpy(&sd->str[sd->len],ptr,len);
+    if (sd->str) {
+      memcpy(sd->str+sd->len,ptr,len);
+      sd->str[sd->len+len]=0;
+    }
     sd->len+=len;
-    sd->str[sd->len]=0;
   }
   return nmemb;
 }
