@@ -27,7 +27,7 @@ int res_search(const char *dname, int class, int type, unsigned char *answer, in
     if (count==__dns_search) break;
     Buf[len]='.';
 //    printf("appending %d: %p (%s)\n",count,__dns_domains[count],__dns_domains[count]);
-    strncpy(Buf+len+1,__dns_domains[count],MAXDNAME-len-1);
+    memccpy(Buf+len+1,__dns_domains[count],0,MAXDNAME-len-1);
     tmp=Buf;
     ++count;
   }
