@@ -8,7 +8,7 @@ int pthread_mutex_destroy(pthread_mutex_t *mutex)
 {
   __THREAD_INIT();
 
-  if ((mutex->owner)||(mutex->lock.__spinlock)) {
+  if ((mutex->owner)||(mutex->lock.__spinlock==PTHREAD_SPIN_LOCKED)) {
     return EBUSY;
   }
   return 0;
