@@ -7,15 +7,10 @@ FILE *__stdio_root;
 
 int __stdio_atexit=0;
 
-void __stdio_flushall(void);
 void __stdio_flushall(void) {
   fflush(0);
 }
 
-extern int __fflush_stdin(void);
-extern int __fflush_stdout(void);
-extern int __fflush_stderr(void);
-
 int fflush(FILE *stream) {
   if (stream==0) {
     int res;
@@ -33,14 +28,15 @@ int fflush(FILE *stream) {
     register int tmp;
     if ((tmp=stream->bm-stream->bs)) {
       lseek(stream->fd,tmp,SEEK_CUR);
-      stream->bs=0;
     }
-  } else
+    stream->bs=stream->bm=0;
+  } else {
     if (stream->bm && write(stream->fd,stream->buf,stream->bm)!=(int)stream->bm) {
       stream->flags|=ERRORINDICATOR;
       return -1;
     }
-  stream->bm=0;
+    stream->bm=0;
+  }
   return 0;
 }
 
@@ -54,10 +50,14 @@ int __fflush4(FILE *stream,int next) {
     stream->flags=(stream->flags&~BUFINPUT)|next;
     return res;
   }
+  if (stream->fd==0) __fflush_stdout();
   return 0;
 }
 
-int __buffered_outs(const char *s,size_t len) {
+/* Internal function, has no prototype.
+ * This is defined here because of the weak symbol ELF semantics */
+int __stdio_outs(const char *s,size_t len);
+int __stdio_outs(const char *s,size_t len) {
   return fwrite(s,1,(size_t)len,stdout);
 }
 
