@@ -4,9 +4,9 @@
 
 int main(int argc,char* argv[]) {
   long a,b;
-  asm("rdtsc":"=a"(a)::"edx");
+  asm("rdtsc":"=A"(a));
   if (!fork()) { execve(argv[1],argv+1,environ); exit(1); }
   wait(0);
-  asm("rdtsc":"=a"(b)::"edx");
+  asm("rdtsc":"=A"(b));
   printf("%lu cycles\n",b-a);
 }
