@@ -3,7 +3,7 @@
 
 int main(int argc,char *argv[]) {
   struct servent* se;
-  if (se=getservbyname("pop-3","tcp")) {
+  if (se=getservbyname("pop","tcp")) {
     int i;
     printf("name %s\tport %d\tproto %s\n",se->s_name,ntohs(se->s_port),se->s_proto);
     for (i=0; i<16; ++i) {
